package com.biganto.visual.roompark.presentation.screen.photo.util

import android.view.View
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.domain.model.PhotoModel
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonRecyclerAdapter
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonViewHolder
import com.github.chrisbanes.photoview.PhotoView
import com.google.android.material.textview.MaterialTextView
import com.squareup.picasso.Picasso


/**
 * Created by Vladislav Bogdashkin on 15.10.2019.
 */
class PhotoViewerAdapter : CommonRecyclerAdapter<PhotoViewerViewHolder, PhotoModel>() {

    override val vhKlazz = PhotoViewerViewHolder::class

    override fun getVhLayout(): Int = R.layout.photo_page_viewholder

    fun getItemPosition(model: PhotoModel) = getItemPosition(model.photoId)

    fun getItemPosition(modelId: Int) = list.indexOfFirst {
        it.photoId == modelId
    }
}


class PhotoViewerViewHolder(itemView: View) : CommonViewHolder<PhotoModel>(itemView) {

    @BindView(R.id.photo_view) lateinit var photoView:PhotoView
    @BindView(R.id.photo_description) lateinit var photoDesc:MaterialTextView

    val picassoAsync: Picasso by lazy {
        return@lazy RoomParkApplication.component.providePicassoAsync()
    }

    override fun onViewBound(model: PhotoModel) {

        photoDesc.visibility = if (model.description.isNullOrBlank()) View.GONE else View.VISIBLE
        model.description?.let{ photoDesc.text = it}
        model.optimalResolution(photoView.width,photoView.height).let {

            picassoAsync
                .load(it.url)
//                .transform(BlurTransformation(itemView.context,13,2))
                .into(photoView)
        }
    }
}
